"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatter = exports.originInputs = void 0;
const common_1 = require("@tencent-serverless-framework/common");
const fs = require("fs");
const path = require("path");
/** 用于获取证书文件信息 */
function getCertPathContent(target) {
    let content = '';
    try {
        const stat = fs.statSync(target);
        if (stat.isFile()) {
            if (path.isAbsolute(target)) {
                content = fs.readFileSync(target, 'base64');
            }
            else {
                content = fs.readFileSync(path.join(process.cwd(), target), 'base64');
            }
        }
    }
    catch (e) {
        // target is string just return
        content = target;
    }
    return content;
}
/**
 * 格式化证书
 * @param {object} inputs cert info
 */
function certInputs(inputs) {
    var _a;
    if (inputs.certId) {
        return {
            CertId: inputs.certId,
        };
    }
    return {
        Certificate: getCertPathContent(inputs.certificate),
        PrivateKey: getCertPathContent(inputs.privateKey),
        Message: (_a = inputs.remarks) !== null && _a !== void 0 ? _a : '',
    };
}
/** 格式化 CDN 源信息 */
function originInputs(inputs) {
    var _a;
    const originInfo = {
        Origins: inputs.origins,
        OriginType: inputs.originType,
        OriginPullProtocol: inputs.originPullProtocol,
        ServerName: inputs.serverName,
    };
    if (inputs.originType === 'cos') {
        return {
            ...originInfo,
            ServerName: (_a = inputs.origins[0]) !== null && _a !== void 0 ? _a : '',
            CosPrivateAccess: 'off',
        };
    }
    if (inputs.originType === 'domain') {
        if (inputs.backupOrigins) {
            return {
                ...originInfo,
                BackupOrigins: inputs.backupOrigins,
                BackupOriginType: inputs.backupOriginType,
                BackupServerName: inputs.backupServerName,
            };
        }
    }
    return originInfo;
}
exports.originInputs = originInputs;
/** DeployInputs 转 AddCdnDomainRequest */
function deployInputs(inputs) {
    var _a, _b, _c, _d, _e, _f;
    const cdnInputs = common_1.pascalCaseProperty(inputs);
    if (cdnInputs.Https) {
        const hs = inputs.https;
        cdnInputs.Https = {
            Switch: (_a = hs === null || hs === void 0 ? void 0 : hs.switch) !== null && _a !== void 0 ? _a : 'on',
            Http2: (_b = hs === null || hs === void 0 ? void 0 : hs.http2) !== null && _b !== void 0 ? _b : 'off',
            OcspStapling: (_c = hs === null || hs === void 0 ? void 0 : hs.ocspStapling) !== null && _c !== void 0 ? _c : 'off',
            VerifyClient: (_d = hs === null || hs === void 0 ? void 0 : hs.verifyClient) !== null && _d !== void 0 ? _d : 'off',
            CertInfo: certInputs(hs === null || hs === void 0 ? void 0 : hs.certInfo),
        };
    }
    if (inputs.forceRedirect && inputs.https) {
        cdnInputs.ForceRedirect = {
            Switch: (_e = inputs.forceRedirect.switch) !== null && _e !== void 0 ? _e : 'on',
            RedirectStatusCode: (_f = inputs.forceRedirect.redirectStatusCode) !== null && _f !== void 0 ? _f : 301,
            RedirectType: 'https',
        };
    }
    cdnInputs.Origin = originInputs(inputs.origin);
    /** 移除 CDN 参数中多余的参数，否则会导致部署失败 */
    cdnInputs.OldState = undefined;
    cdnInputs.Async = undefined;
    cdnInputs.OnlyRefresh = undefined;
    cdnInputs.RefreshCdn = undefined;
    cdnInputs.PushCdn = undefined;
    return common_1.removeUndefined(cdnInputs);
}
exports.formatter = {
    originInputs,
    certInputs,
    deployInputs,
};
