import { CdnDeployInputs } from '../src/interface';
import { Cdn } from '../src/';
import { sleep, deepClone } from '@tencent-serverless-framework/common';
import { formatter } from '../src/formatter';

describe('Cdn', () => {
  const credentials = {
    SecretId: process.env.TENCENT_SECRET_ID,
    SecretKey: process.env.TENCENT_SECRET_KEY,
  };

  const inputs: CdnDeployInputs = {
    async: false,
    area: 'overseas',
    domain: process.env.SUB_DOMAIN!,
    origin: {
      origins: [
        `${process.env.BUCKET}-${process.env.TENCENT_APP_ID}.cos.${process.env.REGION}.myqcloud.com`,
      ],
      originType: 'cos',
      originPullProtocol: 'https',
    },
    serviceType: 'web',
    https: {
      switch: 'on',
      http2: 'on',
      certInfo: {
        certId: process.env.SUB_DOMAIN_CERT_ID,
      },
    },
    forceRedirect: {
      switch: 'on',
      redirectType: 'https',
      redirectStatusCode: 301,
    },
  };
  const cdn = new Cdn(credentials);

  test('should formatter', async () => {
    const cdnInputs = formatter.deployInputs(inputs);
    expect(cdnInputs).not.toHaveProperty('Async');
    expect(cdnInputs).not.toHaveProperty('async');
  });

  test('should deploy CDN success with originType = cos', async () => {
    await sleep(5000);
    const inputsBackup = deepClone(inputs);
    const res = await cdn.deploy(inputs);
    expect(res).toEqual({
      https: true,
      domain: inputs.domain,
      origins: inputs.origin.origins,
      cname: `${inputs.domain}.cdn.dnsv1.com`,
      inputCache: JSON.stringify(inputs),
      resourceId: expect.stringContaining('cdn-'),
    });
    expect(inputs).toEqual(inputsBackup);
  });

  test('should deploy CDN success with originType = domain', async () => {
    await sleep(5000);

    inputs.origin.originType = 'domain';
    const inputsBackup = deepClone(inputs);
    const res = await cdn.deploy(inputs);
    expect(res).toEqual({
      https: true,
      domain: inputs.domain,
      origins: inputs.origin.origins,
      cname: `${inputs.domain}.cdn.dnsv1.com`,
      inputCache: JSON.stringify(inputs),
      resourceId: expect.stringContaining('cdn-'),
    });
    expect(inputs).toEqual(inputsBackup);
  });

  test('should remove CDN success', async () => {
    const res = await cdn.remove(inputs);
    const inputsBackup = deepClone(inputs);
    expect(res).toEqual({});
    const detail = await cdn.getCdnByDomain(inputs.domain);
    expect(detail).toBeUndefined();
    expect(inputs).toEqual(inputsBackup);
  });
});
